@@ -30,7 +30,7 @@ async fn main() -> Result<(), Box<dyn std::error::Error>> {
             let mut data: MutexGuard<Vec<Paste>> = pastes_timer.lock().unwrap();
             // remove paste if lifetime exceed 60 minutes
             data.retain(|x| {
-                x.lifetime.elapsed() < Duration::from_secs(config.lifetime as u64 * 60)
+                x.lifetime.elapsed() < Duration::from_secs(config.lifetime * 60)
             });
 
             if data.len() > config.max_pastes {
